<?php

use Dotenv\Dotenv;
use Dotenv\Repository\Adapter\EnvConstAdapter;
use Dotenv\Repository\RepositoryBuilder;

define('WP_ROOT_DIR', dirname(__DIR__));

/**
 * Load .env variables in $_ENV with dotenv
 */

$repository = RepositoryBuilder::createWithNoAdapters()
    ->addAdapter(EnvConstAdapter::class)
    ->immutable()
    ->make();

$dotenv = Dotenv::create($repository, WP_ROOT_DIR, '.env');
$dotenv->load();

/**
 * Set up our global environment constant and load its config first
 * Default: production
 */
foreach ($_ENV as $label => $value) {
    define($label, $value);
}


$envConfig = __DIR__ . '/environments/' . WP_ENVIRONMENT_TYPE . '.php';

if (!file_exists($envConfig)) {
    echo $envConfig . __('Is not set as an environment file', 'puddinq');
}

/**
 * Custom Content Directory
 */
define('WP_CONTENT_DIR', WP_ROOT_DIR . '/content');
define('WP_CONTENT_URL', WP_HOME . '/content');

/**
 * DB settings
 */
define('DB_CHARSET', 'utf8');
define('DB_COLLATE', '');
$table_prefix = $_ENV['DB_PREFIX'];


/**
 * Network
 */
define('WP_ALLOW_MULTISITE', false);

if (WP_ALLOW_MULTISITE == true) {
    $wpHome = explode('/', WP_HOME);
    $domainCurrentSite = $wpHome[2];

    define('MULTISITE', false);
    define('SUBDOMAIN_INSTALL', false);
    define('DOMAIN_CURRENT_SITE', $domainCurrentSite);
    define('PATH_CURRENT_SITE', '/');
    define('SITE_ID_CURRENT_SITE', 1);
    define('BLOG_ID_CURRENT_SITE', 1);
}

/**
 * Custom Settings
 */
define('DISALLOW_FILE_EDIT', true);

/**
 * Bootstrap WordPress
 */
if (!defined('ABSPATH')) {
    define('ABSPATH', WP_ROOT_DIR . '/wp/');
}
